% Main script.
close all
clear all
clc

% defining all defined variables
mainVars

% x0 is the starting point of the x axis
x0           = -4.5;

% xF is the end point of the x axis
xf           = 4.5;

% X starts at -4.5 and ends at 4.5 with 200! elements in between
X            = linspace(x0,xf,N);

% calling out function setProbelem
[rho, u, P]  = setProblem(X);


E = (P/(gam-1)) + 0.5.*rho.*u.*u;
rhou         = rho.*u;

% Display Sod's Shock Tube Problem Initial Variables:
% Specific Heat Ratio
% After-shock density
% After-shock velocity
% After-shock pressure
% Preshock-density
% Pre-shock velocity
% Pre-shock pressure

xxxx         = sprintf('Initialization Successful.');
disp(xxxx)

% defining the initial time, RHSmass, RHSmom, and RHSNRG
time         = 0.0;
RHSmass      = 0.0;
RHSmom       = 0.0;
RHSNRG       = 0.0;

while (time < timeF)
    
    if (time + dt > timeF)
        dt = timeF-time;
    end
    
    rhotemp  = rho;
    rhoutemp = rhou;
    Etemp    = E;
    
    % First of 3 RK substeps for time advancement
    CompRHS
    rhotemp  = rho  + dt*RHSmass;
    rhoutemp = rhou + dt*RHSmom;
    Etemp    = E    + dt*RHSNRG;
    
    % Second of 3 RK substeps for time advancement
    
    CompRHS
    rhotemp  = rk21 * rho  + rk22*rhotemp  + dt*rk23*RHSmass;
    rhoutemp = rk21 * rhou + rk22*rhoutemp + dt*rk23*RHSmom;
    Etemp    = rk21 * E    + rk22*Etemp    + dt*rk23*RHSNRG;
    
    
    % Third of 3 RK substeps for time advancement
    CompRHS
    rho      = rk31 * rho  + rk32*rhotemp  + dt*rk33*RHSmass;
    rhou     = rk31 * rhou + rk32*rhoutemp + dt*rk33*RHSmom;
    E        = rk31 * E    + rk32*Etemp    + dt*rk33*RHSNRG;
    
    time     = time + dt;
    
    
    
    u        = rhou./rho;
    P        = (gam-1.0)*(E-0.5*rho.*u.*u);
   
    
    
end

% plot X vs rho
plot(X,rho);


% Displays Final Time
xxxx = sprintf('Final Time = %d', (timeF));
disp(xxxx)

% Displays paramter N
xxxx = sprintf('N = %d', (N));
disp(xxxx)

%Displays grid spacing
xxxx = sprintf('Grid Spacing = %d', (dx));
disp(xxxx)

% Displays the time step
xxxx = sprintf('Time Step = %d', (CFL*timeF/(N-1)));
disp(xxxx)

% Displays parameter CFL
xxxx = sprintf('CFL = %d', (CFL));
disp(xxxx)

